@@ -19,7 +19,7 @@ from warpseq.model.evaluator import RandomRange, Probability
 # setup API and song
 
 api = WarpApi()
-api.song.edit(tempo=60)
+api.song.edit(tempo=120)
 
 # ======================================================================================================================
 # setup instruments
@@ -54,11 +54,11 @@ api.patterns.add(name='basic', slots=[
 
 api.patterns.add(name='chords', slots=[
     Slot(degree=1, chord_type='major'),
+    Slot(rest=True),
     Slot(degree=4, chord_type='major'),
-    Slot(degree=6, chord_type='major'),
+    Slot(rest=True),
     Slot(degree=5, chord_type='major'),
-    Slot(degree=4, chord_type='power'),
-    Slot(degree=5, chord_type='power')
+    Slot(rest=True)
 ])
 
 # setup transforms
@@ -157,10 +157,10 @@ api.scenes.add(name='scene_END', rate=0.5, auto_advance=True)
 # setup clips
 
 api.clips.add(name='chord strum', scene='scene_1', track='lead', scales=['C-major'],
-              patterns=['chords'], transforms=['basic arp'], repeat=1, auto_scene_advance=True)
+              patterns=['chords'], transforms=['basic arp'], repeat=2, auto_scene_advance=True)
 
 api.clips.add(name='chord octave arp', scene='scene_2', track='lead', scales=['C-major'],
-              patterns=['chords'], transforms=['octave arp'], repeat=1, auto_scene_advance=True)
+              patterns=['chords'], transforms=['octave arp'], repeat=2, auto_scene_advance=True)
 
 api.clips.add(name='chord velocity', scene='scene_3', track='lead', scales=['C-major'],
               patterns=['chords'], transforms=['velocity arp'], repeat=1, auto_scene_advance=True)
