@@ -66,7 +66,7 @@ class Chord(object):
         if self.notes is None:
             offsets = CHORD_TYPES[self.chord_type]
             notes = [root.copy()]
-            notes.extend([root.transpose(semitones=offset) for offset in offsets])
+            notes.extend([root.copy().transpose(semitones=offset) for offset in offsets])
             self.notes = notes
 
     def shiftable(self):
