@@ -38,7 +38,7 @@ class Note(object):
                   'ccs', 'deferred_expressions', 'from_context')
 
     def __init__(self, name=None, octave=0, tie=False, length=None, start_time=None, end_time=None,
-                 velocity=DEFAULT_VELOCITY, from_scale=None, from_parser=None, repeat=1, length_mod=1, tied=0, delay=0,
+                 velocity=DEFAULT_VELOCITY, from_scale=None, from_parser=None, repeat=None, length_mod=1, tied=0, delay=0,
                  no_shift=False, muted=False, track_copy=None, ccs=None, deferred_expressions=None,
                  from_context=None):
 
