@@ -8,6 +8,7 @@ from warpseq.model.evaluator import Evaluator, set_variable
 from warpseq.model.note import Note
 from warpseq.model.registers import get_first_playing_note
 
+
 def evaluate(context=None, subject=None, how=None):
     if isinstance(how, Evaluator):
         res = how.evaluate(context=context, subject=input)
@@ -76,9 +77,47 @@ class Slot(BaseSlot):
         self.degree_shift = degree_shift
         self.octave_shift = octave_shift
 
-    def evaluate(self, context, note):
+    def _standardize_input(self, note):
 
-        note = note.copy()
+        from warpseq.model.note import Note
+        from warpseq.model.chord import Chord
+
+        if type(note) == Chord:
+            return note
+        elif type(note) == Note:
+            return note
+        elif type(note) == list:
+            if len(note) == 1:
+                return note[0]
+            else:
+                return Chord(notes=note)
+        else:
+            raise Exception("???")
+
+    # ==================================================================================================================
+
+    def evaluate(self, context, obj):
+
+        # evaluates a Note or Chord or None and always returns a Chord or None
+
+        from warpseq.model.note import Note
+        from warpseq.model.chord import Chord
+
+        result = self._compute(context, obj)
+
+        if not result:
+            return None
+        elif type(result) == Note:
+            return Chord(notes=[result])
+        return result
+
+    # ==================================================================================================================
+
+    def _compute(self, context, note):
+
+        # FIXME: rename 'note' to 'obj'
+
+        note = self._standardize_input(note).copy()
 
         if note.length is None:
             note.length = context.base_length
@@ -121,7 +160,7 @@ class Slot(BaseSlot):
             assert note.length is not None
 
         if self.degree:
-            note = note.scale_transpose(context.scale, evaluate(context=context, subject=note, how=self.degree))
+            note = note.scale_transpose(context.scale, evaluate(context=context, subject=note, how=self.degree) -1 )
 
         if self.octave is not None:
             res = evaluate(context=context, subject=note, how=self.octave)
@@ -138,10 +177,10 @@ class Slot(BaseSlot):
             note = note.scale_transpose(context.scale, evaluate(context=context, subject=note, how=self.degree_shift))
 
         if self.repeats:
-            note = note.with_repeats(evaluate(context=context, subject=note, how=self.repeats))
+            note = note.with_repeat(evaluate(context=context, subject=note, how=self.repeats))
 
         if self.length and self.length != 1:
-            note = note.with_length(evaluate(context=context, subject=note, how=self.length))
+            note = note.with_length_mod(evaluate(context=context, subject=note, how=self.length))
 
         if self.sharp and evaluate(context=context, subject=note, how=self.sharp):
             note = note.transpose(semitones=1)
@@ -173,7 +212,7 @@ class Slot(BaseSlot):
                 note = note.with_cc(k,v)
 
         if self.delay:
-            note = note.with_delay(evaluate(context=context, subject=note, how=v))
+            note = note.with_delay(evaluate(context=context, subject=note, how=self.delay))
 
         if self.velocity is not None:
             note = note.with_velocity(evaluate(context=context, subject=note, how=self.velocity))
@@ -183,6 +222,7 @@ class Slot(BaseSlot):
 
         return note
 
+# ======================================================================================================================
 
 def defer_track_grab(context=None, track=None, subject=None, how=None):
     other_track = context.song.find_track_by_name(how)
