@@ -21,7 +21,7 @@ def _get_note_number(note, instrument):
     max_o = instrument.max_octave
     min_o = instrument.min_octave
 
-    note2 = note.transpose(octaves=instrument.base_octave)
+    note2 = note.copy().transpose(octaves=instrument.base_octave)
 
     if note2.octave > max_o:
         note2.octave = max_o
@@ -123,7 +123,7 @@ class RealtimeEngine(object):
                 self.player.inject_off_event(event)
                 for instrument in self.track.get_instruments_to_play():
                     if not instrument.muted:
-                        #print("PLAY: %s / %s" % (instrument.name, event.note))
+                        #print("*************>> PLAY: %s / %s" % (instrument.name, event.note))
                         midi_note_on(instrument.get_midi_out(), instrument.channel, _get_note_number(event.note, instrument), velocity)
 
 
